summaryrefslogtreecommitdiffstats
path: root/kio/kio/kacl.h
diff options
context:
space:
mode:
Diffstat (limited to 'kio/kio/kacl.h')
-rw-r--r--kio/kio/kacl.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/kio/kio/kacl.h b/kio/kio/kacl.h
index 53bc762b0..6fe415603 100644
--- a/kio/kio/kacl.h
+++ b/kio/kio/kacl.h
@@ -111,24 +111,24 @@ public:
/** @return the basic (owner/group/others) part of the ACL as a mode_t */
mode_t basePermissions() const;
/** The interface to the extended ACL. This is a mask, permissions for
* n named users and permissions for m named groups. */
/**
- * Return whether the ACL contains extended entries or can be expressed
+ * Return whether the ACL tqcontains extended entries or can be expressed
* using only basic file permissions.
- * @return whether the ACL contains extended entries */
+ * @return whether the ACL tqcontains extended entries */
bool isExtended() const;
/**
* Return the entry for the permissions mask if there is one and sets
* @p exists to true. If there is no such entry, @p exists is set to false.
- * @return the permissions mask entry */
- unsigned short maskPermissions( bool &exists ) const;
+ * @return the permissions tqmask entry */
+ unsigned short tqmaskPermissions( bool &exists ) const;
- /** Set the permissions mask for the ACL. Permissions set for individual
- * entries will be masked with this, such that their effective permissions
- * are the result of the logical and of their entry and the mask.
+ /** Set the permissions tqmask for the ACL. Permissions set for individual
+ * entries will be tqmasked with this, such that their effective permissions
+ * are the result of the logical and of their entry and the tqmask.
* @return success or failure */
bool setMaskPermissions( unsigned short );
@@ -111,24 +111,24 @@ public:
/** @return the basic (owner/group/others) part of the ACL as a mode_t */
mode_t basePermissions() const;
- /** The interface to the extended ACL. This is a mask, permissions for
+ /** The interface to the extended ACL. This is a tqmask, permissions for
* n named users and permissions for m named groups. */
/**
@@ -111,24 +111,24 @@ public:
bool isExtended() const;
/**
- * Return the entry for the permissions mask if there is one and sets
+ * Return the entry for the permissions tqmask if there is one and sets
* @p exists to true. If there is no such entry, @p exists is set to false.